# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings

from yandex.cloud.ai.translate.v2 import translation_service_pb2 as yandex_dot_cloud_dot_ai_dot_translate_dot_v2_dot_translation__service__pb2

GRPC_GENERATED_VERSION = '1.70.0'
GRPC_VERSION = grpc.__version__
_version_not_supported = False

try:
    from grpc._utilities import first_version_is_lower
    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True

if _version_not_supported:
    raise RuntimeError(
        f'The grpc package installed is at version {GRPC_VERSION},'
        + f' but the generated code in yandex/cloud/ai/translate/v2/translation_service_pb2_grpc.py depends on'
        + f' grpcio>={GRPC_GENERATED_VERSION}.'
        + f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}'
        + f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.'
    )


class TranslationServiceStub(object):
    """A set of methods for the Translate service.

    Make sure you send your [authentication](/docs/translate/api-ref/authentication) credentials in the `Authorization` header of each request.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Translate = channel.unary_unary(
                '/yandex.cloud.ai.translate.v2.TranslationService/Translate',
                request_serializer=yandex_dot_cloud_dot_ai_dot_translate_dot_v2_dot_translation__service__pb2.TranslateRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_ai_dot_translate_dot_v2_dot_translation__service__pb2.TranslateResponse.FromString,
                _registered_method=True)
        self.DetectLanguage = channel.unary_unary(
                '/yandex.cloud.ai.translate.v2.TranslationService/DetectLanguage',
                request_serializer=yandex_dot_cloud_dot_ai_dot_translate_dot_v2_dot_translation__service__pb2.DetectLanguageRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_ai_dot_translate_dot_v2_dot_translation__service__pb2.DetectLanguageResponse.FromString,
                _registered_method=True)
        self.ListLanguages = channel.unary_unary(
                '/yandex.cloud.ai.translate.v2.TranslationService/ListLanguages',
                request_serializer=yandex_dot_cloud_dot_ai_dot_translate_dot_v2_dot_translation__service__pb2.ListLanguagesRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_ai_dot_translate_dot_v2_dot_translation__service__pb2.ListLanguagesResponse.FromString,
                _registered_method=True)


class TranslationServiceServicer(object):
    """A set of methods for the Translate service.

    Make sure you send your [authentication](/docs/translate/api-ref/authentication) credentials in the `Authorization` header of each request.
    """

    def Translate(self, request, context):
        """Translates the text to the specified language.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DetectLanguage(self, request, context):
        """Detects the language of the text.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListLanguages(self, request, context):
        """Retrieves the list of supported languages.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_TranslationServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Translate': grpc.unary_unary_rpc_method_handler(
                    servicer.Translate,
                    request_deserializer=yandex_dot_cloud_dot_ai_dot_translate_dot_v2_dot_translation__service__pb2.TranslateRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_ai_dot_translate_dot_v2_dot_translation__service__pb2.TranslateResponse.SerializeToString,
            ),
            'DetectLanguage': grpc.unary_unary_rpc_method_handler(
                    servicer.DetectLanguage,
                    request_deserializer=yandex_dot_cloud_dot_ai_dot_translate_dot_v2_dot_translation__service__pb2.DetectLanguageRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_ai_dot_translate_dot_v2_dot_translation__service__pb2.DetectLanguageResponse.SerializeToString,
            ),
            'ListLanguages': grpc.unary_unary_rpc_method_handler(
                    servicer.ListLanguages,
                    request_deserializer=yandex_dot_cloud_dot_ai_dot_translate_dot_v2_dot_translation__service__pb2.ListLanguagesRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_ai_dot_translate_dot_v2_dot_translation__service__pb2.ListLanguagesResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'yandex.cloud.ai.translate.v2.TranslationService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('yandex.cloud.ai.translate.v2.TranslationService', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class TranslationService(object):
    """A set of methods for the Translate service.

    Make sure you send your [authentication](/docs/translate/api-ref/authentication) credentials in the `Authorization` header of each request.
    """

    @staticmethod
    def Translate(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.ai.translate.v2.TranslationService/Translate',
            yandex_dot_cloud_dot_ai_dot_translate_dot_v2_dot_translation__service__pb2.TranslateRequest.SerializeToString,
            yandex_dot_cloud_dot_ai_dot_translate_dot_v2_dot_translation__service__pb2.TranslateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def DetectLanguage(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.ai.translate.v2.TranslationService/DetectLanguage',
            yandex_dot_cloud_dot_ai_dot_translate_dot_v2_dot_translation__service__pb2.DetectLanguageRequest.SerializeToString,
            yandex_dot_cloud_dot_ai_dot_translate_dot_v2_dot_translation__service__pb2.DetectLanguageResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ListLanguages(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.ai.translate.v2.TranslationService/ListLanguages',
            yandex_dot_cloud_dot_ai_dot_translate_dot_v2_dot_translation__service__pb2.ListLanguagesRequest.SerializeToString,
            yandex_dot_cloud_dot_ai_dot_translate_dot_v2_dot_translation__service__pb2.ListLanguagesResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)
