# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings

from yandex.cloud.loadtesting.agent.v1 import job_service_pb2 as yandex_dot_cloud_dot_loadtesting_dot_agent_dot_v1_dot_job__service__pb2

GRPC_GENERATED_VERSION = '1.70.0'
GRPC_VERSION = grpc.__version__
_version_not_supported = False

try:
    from grpc._utilities import first_version_is_lower
    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True

if _version_not_supported:
    raise RuntimeError(
        f'The grpc package installed is at version {GRPC_VERSION},'
        + f' but the generated code in yandex/cloud/loadtesting/agent/v1/job_service_pb2_grpc.py depends on'
        + f' grpcio>={GRPC_GENERATED_VERSION}.'
        + f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}'
        + f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.'
    )


class JobServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ClaimStatus = channel.unary_unary(
                '/yandex.cloud.loadtesting.agent.v1.JobService/ClaimStatus',
                request_serializer=yandex_dot_cloud_dot_loadtesting_dot_agent_dot_v1_dot_job__service__pb2.ClaimJobStatusRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_loadtesting_dot_agent_dot_v1_dot_job__service__pb2.ClaimJobStatusResponse.FromString,
                _registered_method=True)
        self.Get = channel.unary_unary(
                '/yandex.cloud.loadtesting.agent.v1.JobService/Get',
                request_serializer=yandex_dot_cloud_dot_loadtesting_dot_agent_dot_v1_dot_job__service__pb2.GetJobRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_loadtesting_dot_agent_dot_v1_dot_job__service__pb2.Job.FromString,
                _registered_method=True)
        self.GetSignal = channel.unary_unary(
                '/yandex.cloud.loadtesting.agent.v1.JobService/GetSignal',
                request_serializer=yandex_dot_cloud_dot_loadtesting_dot_agent_dot_v1_dot_job__service__pb2.JobSignalRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_loadtesting_dot_agent_dot_v1_dot_job__service__pb2.JobSignalResponse.FromString,
                _registered_method=True)
        self.GetTransientFile = channel.unary_unary(
                '/yandex.cloud.loadtesting.agent.v1.JobService/GetTransientFile',
                request_serializer=yandex_dot_cloud_dot_loadtesting_dot_agent_dot_v1_dot_job__service__pb2.GetJobTransientFile.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_loadtesting_dot_agent_dot_v1_dot_job__service__pb2.File.FromString,
                _registered_method=True)


class JobServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def ClaimStatus(self, request, context):
        """Claims status for the specified job.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Get(self, request, context):
        """Returns the job for the specified agent.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetSignal(self, request, context):
        """Returns the signal for the specified job.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetTransientFile(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_JobServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'ClaimStatus': grpc.unary_unary_rpc_method_handler(
                    servicer.ClaimStatus,
                    request_deserializer=yandex_dot_cloud_dot_loadtesting_dot_agent_dot_v1_dot_job__service__pb2.ClaimJobStatusRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_loadtesting_dot_agent_dot_v1_dot_job__service__pb2.ClaimJobStatusResponse.SerializeToString,
            ),
            'Get': grpc.unary_unary_rpc_method_handler(
                    servicer.Get,
                    request_deserializer=yandex_dot_cloud_dot_loadtesting_dot_agent_dot_v1_dot_job__service__pb2.GetJobRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_loadtesting_dot_agent_dot_v1_dot_job__service__pb2.Job.SerializeToString,
            ),
            'GetSignal': grpc.unary_unary_rpc_method_handler(
                    servicer.GetSignal,
                    request_deserializer=yandex_dot_cloud_dot_loadtesting_dot_agent_dot_v1_dot_job__service__pb2.JobSignalRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_loadtesting_dot_agent_dot_v1_dot_job__service__pb2.JobSignalResponse.SerializeToString,
            ),
            'GetTransientFile': grpc.unary_unary_rpc_method_handler(
                    servicer.GetTransientFile,
                    request_deserializer=yandex_dot_cloud_dot_loadtesting_dot_agent_dot_v1_dot_job__service__pb2.GetJobTransientFile.FromString,
                    response_serializer=yandex_dot_cloud_dot_loadtesting_dot_agent_dot_v1_dot_job__service__pb2.File.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'yandex.cloud.loadtesting.agent.v1.JobService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('yandex.cloud.loadtesting.agent.v1.JobService', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class JobService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def ClaimStatus(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.loadtesting.agent.v1.JobService/ClaimStatus',
            yandex_dot_cloud_dot_loadtesting_dot_agent_dot_v1_dot_job__service__pb2.ClaimJobStatusRequest.SerializeToString,
            yandex_dot_cloud_dot_loadtesting_dot_agent_dot_v1_dot_job__service__pb2.ClaimJobStatusResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Get(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.loadtesting.agent.v1.JobService/Get',
            yandex_dot_cloud_dot_loadtesting_dot_agent_dot_v1_dot_job__service__pb2.GetJobRequest.SerializeToString,
            yandex_dot_cloud_dot_loadtesting_dot_agent_dot_v1_dot_job__service__pb2.Job.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetSignal(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.loadtesting.agent.v1.JobService/GetSignal',
            yandex_dot_cloud_dot_loadtesting_dot_agent_dot_v1_dot_job__service__pb2.JobSignalRequest.SerializeToString,
            yandex_dot_cloud_dot_loadtesting_dot_agent_dot_v1_dot_job__service__pb2.JobSignalResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetTransientFile(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.loadtesting.agent.v1.JobService/GetTransientFile',
            yandex_dot_cloud_dot_loadtesting_dot_agent_dot_v1_dot_job__service__pb2.GetJobTransientFile.SerializeToString,
            yandex_dot_cloud_dot_loadtesting_dot_agent_dot_v1_dot_job__service__pb2.File.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)
