# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/mdb/greenplum/v1/user.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/mdb/greenplum/v1/user.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(yandex/cloud/mdb/greenplum/v1/user.proto\x12\x1dyandex.cloud.mdb.greenplum.v1\x1a\x1dyandex/cloud/validation.proto\"\x90\x01\n\x04User\x12;\n\x04name\x18\x01 \x01(\tB-\xe8\xc7\x31\x01\xf2\xc7\x31\x1d^[a-zA-Z_][a-zA-Z0-9_]{0,62}$\x8a\xc8\x31\x04\x31-63\x12\x1b\n\x08password\x18\x02 \x01(\tB\t\x8a\xc8\x31\x05\x36-200\x12.\n\x0eresource_group\x18\x03 \x01(\tB\x16\xf2\xc7\x31\x12^[^\\|/*?.,;\"\'<>]+$Bp\n!yandex.cloud.api.mdb.greenplum.v1ZKgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/greenplum/v1;greenplumb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.mdb.greenplum.v1.user_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n!yandex.cloud.api.mdb.greenplum.v1ZKgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/greenplum/v1;greenplum'
  _globals['_USER'].fields_by_name['name']._loaded_options = None
  _globals['_USER'].fields_by_name['name']._serialized_options = b'\350\3071\001\362\3071\035^[a-zA-Z_][a-zA-Z0-9_]{0,62}$\212\3101\0041-63'
  _globals['_USER'].fields_by_name['password']._loaded_options = None
  _globals['_USER'].fields_by_name['password']._serialized_options = b'\212\3101\0056-200'
  _globals['_USER'].fields_by_name['resource_group']._loaded_options = None
  _globals['_USER'].fields_by_name['resource_group']._serialized_options = b'\362\3071\022^[^\\|/*?.,;\"\'<>]+$'
  _globals['_USER']._serialized_start=107
  _globals['_USER']._serialized_end=251
# @@protoc_insertion_point(module_scope)
