# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/mdb/spqr/v1/user_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/mdb/spqr/v1/user_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2
from yandex.cloud.mdb.spqr.v1 import user_pb2 as yandex_dot_cloud_dot_mdb_dot_spqr_dot_v1_dot_user__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n+yandex/cloud/mdb/spqr/v1/user_service.proto\x12\x18yandex.cloud.mdb.spqr.v1\x1a\x1cgoogle/api/annotations.proto\x1a yandex/cloud/api/operation.proto\x1a google/protobuf/field_mask.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\x1a#yandex/cloud/mdb/spqr/v1/user.proto\"d\n\x0eGetUserRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x30\n\tuser_name\x18\x02 \x01(\tB\x1d\xe8\xc7\x31\x01\xf2\xc7\x31\r[a-zA-Z0-9_]*\x8a\xc8\x31\x04<=63\"r\n\x10ListUsersRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\"\x96\x01\n\x1aListUsersAtRevisionRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\x12\x18\n\x08revision\x18\x04 \x01(\x03\x42\x06\xfa\xc7\x31\x02>0\"[\n\x11ListUsersResponse\x12-\n\x05users\x18\x01 \x03(\x0b\x32\x1e.yandex.cloud.mdb.spqr.v1.User\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"l\n\x11\x43reateUserRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x35\n\tuser_spec\x18\x02 \x01(\x0b\x32\".yandex.cloud.mdb.spqr.v1.UserSpec\";\n\x12\x43reateUserMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\x12\x11\n\tuser_name\x18\x02 \x01(\t\"\xd6\x02\n\x11UpdateUserRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x30\n\tuser_name\x18\x02 \x01(\tB\x1d\xe8\xc7\x31\x01\xf2\xc7\x31\r[a-zA-Z0-9_]*\x8a\xc8\x31\x04<=63\x12/\n\x0bupdate_mask\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12\x1b\n\x08password\x18\x04 \x01(\tB\t\x8a\xc8\x31\x05\x38-128\x12\x39\n\x0bpermissions\x18\x05 \x03(\x0b\x32$.yandex.cloud.mdb.spqr.v1.Permission\x12\x38\n\x08settings\x18\x06 \x01(\x0b\x32&.yandex.cloud.mdb.spqr.v1.UserSettings\x12*\n\x06grants\x18\x07 \x03(\tB\x1a\xf2\xc7\x31\x0e[a-zA-Z0-9_-]*\x8a\xc8\x31\x04<=63\";\n\x12UpdateUserMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\x12\x11\n\tuser_name\x18\x02 \x01(\t\"g\n\x11\x44\x65leteUserRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x30\n\tuser_name\x18\x02 \x01(\tB\x1d\xe8\xc7\x31\x01\xf2\xc7\x31\r[a-zA-Z0-9_]*\x8a\xc8\x31\x04<=63\";\n\x12\x44\x65leteUserMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\x12\x11\n\tuser_name\x18\x02 \x01(\t2\xa1\x08\n\x0bUserService\x12\x91\x01\n\x03Get\x12(.yandex.cloud.mdb.spqr.v1.GetUserRequest\x1a\x1e.yandex.cloud.mdb.spqr.v1.User\"@\x82\xd3\xe4\x93\x02:\x12\x38/managed-spqr/v1/clusters/{cluster_id}/users/{user_name}\x12\x95\x01\n\x04List\x12*.yandex.cloud.mdb.spqr.v1.ListUsersRequest\x1a+.yandex.cloud.mdb.spqr.v1.ListUsersResponse\"4\x82\xd3\xe4\x93\x02.\x12,/managed-spqr/v1/clusters/{cluster_id}/users\x12\xa9\x01\n\x0eListAtRevision\x12\x34.yandex.cloud.mdb.spqr.v1.ListUsersAtRevisionRequest\x1a+.yandex.cloud.mdb.spqr.v1.ListUsersResponse\"4\x82\xd3\xe4\x93\x02.\x12,/managed-spqr/v1/clusters/{cluster_id}/users\x12\xaf\x01\n\x06\x43reate\x12+.yandex.cloud.mdb.spqr.v1.CreateUserRequest\x1a!.yandex.cloud.operation.Operation\"U\xb2\xd2*\x1a\n\x12\x43reateUserMetadata\x12\x04User\x82\xd3\xe4\x93\x02\x31\",/managed-spqr/v1/clusters/{cluster_id}/users:\x01*\x12\xbb\x01\n\x06Update\x12+.yandex.cloud.mdb.spqr.v1.UpdateUserRequest\x1a!.yandex.cloud.operation.Operation\"a\xb2\xd2*\x1a\n\x12UpdateUserMetadata\x12\x04User\x82\xd3\xe4\x93\x02=28/managed-spqr/v1/clusters/{cluster_id}/users/{user_name}:\x01*\x12\xc9\x01\n\x06\x44\x65lete\x12+.yandex.cloud.mdb.spqr.v1.DeleteUserRequest\x1a!.yandex.cloud.operation.Operation\"o\xb2\xd2*+\n\x12\x44\x65leteUserMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02:*8/managed-spqr/v1/clusters/{cluster_id}/users/{user_name}Ba\n\x1cyandex.cloud.api.mdb.spqr.v1ZAgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/spqr/v1;spqrb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.mdb.spqr.v1.user_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\034yandex.cloud.api.mdb.spqr.v1ZAgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/spqr/v1;spqr'
  _globals['_GETUSERREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_GETUSERREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_GETUSERREQUEST'].fields_by_name['user_name']._loaded_options = None
  _globals['_GETUSERREQUEST'].fields_by_name['user_name']._serialized_options = b'\350\3071\001\362\3071\r[a-zA-Z0-9_]*\212\3101\004<=63'
  _globals['_LISTUSERSREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_LISTUSERSREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTUSERSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTUSERSREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\0060-1000'
  _globals['_LISTUSERSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTUSERSREQUEST'].fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _globals['_LISTUSERSATREVISIONREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_LISTUSERSATREVISIONREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTUSERSATREVISIONREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTUSERSATREVISIONREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\0060-1000'
  _globals['_LISTUSERSATREVISIONREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTUSERSATREVISIONREQUEST'].fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _globals['_LISTUSERSATREVISIONREQUEST'].fields_by_name['revision']._loaded_options = None
  _globals['_LISTUSERSATREVISIONREQUEST'].fields_by_name['revision']._serialized_options = b'\372\3071\002>0'
  _globals['_CREATEUSERREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_CREATEUSERREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_UPDATEUSERREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_UPDATEUSERREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_UPDATEUSERREQUEST'].fields_by_name['user_name']._loaded_options = None
  _globals['_UPDATEUSERREQUEST'].fields_by_name['user_name']._serialized_options = b'\350\3071\001\362\3071\r[a-zA-Z0-9_]*\212\3101\004<=63'
  _globals['_UPDATEUSERREQUEST'].fields_by_name['password']._loaded_options = None
  _globals['_UPDATEUSERREQUEST'].fields_by_name['password']._serialized_options = b'\212\3101\0058-128'
  _globals['_UPDATEUSERREQUEST'].fields_by_name['grants']._loaded_options = None
  _globals['_UPDATEUSERREQUEST'].fields_by_name['grants']._serialized_options = b'\362\3071\016[a-zA-Z0-9_-]*\212\3101\004<=63'
  _globals['_DELETEUSERREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_DELETEUSERREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_DELETEUSERREQUEST'].fields_by_name['user_name']._loaded_options = None
  _globals['_DELETEUSERREQUEST'].fields_by_name['user_name']._serialized_options = b'\350\3071\001\362\3071\r[a-zA-Z0-9_]*\212\3101\004<=63'
  _globals['_USERSERVICE'].methods_by_name['Get']._loaded_options = None
  _globals['_USERSERVICE'].methods_by_name['Get']._serialized_options = b'\202\323\344\223\002:\0228/managed-spqr/v1/clusters/{cluster_id}/users/{user_name}'
  _globals['_USERSERVICE'].methods_by_name['List']._loaded_options = None
  _globals['_USERSERVICE'].methods_by_name['List']._serialized_options = b'\202\323\344\223\002.\022,/managed-spqr/v1/clusters/{cluster_id}/users'
  _globals['_USERSERVICE'].methods_by_name['ListAtRevision']._loaded_options = None
  _globals['_USERSERVICE'].methods_by_name['ListAtRevision']._serialized_options = b'\202\323\344\223\002.\022,/managed-spqr/v1/clusters/{cluster_id}/users'
  _globals['_USERSERVICE'].methods_by_name['Create']._loaded_options = None
  _globals['_USERSERVICE'].methods_by_name['Create']._serialized_options = b'\262\322*\032\n\022CreateUserMetadata\022\004User\202\323\344\223\0021\",/managed-spqr/v1/clusters/{cluster_id}/users:\001*'
  _globals['_USERSERVICE'].methods_by_name['Update']._loaded_options = None
  _globals['_USERSERVICE'].methods_by_name['Update']._serialized_options = b'\262\322*\032\n\022UpdateUserMetadata\022\004User\202\323\344\223\002=28/managed-spqr/v1/clusters/{cluster_id}/users/{user_name}:\001*'
  _globals['_USERSERVICE'].methods_by_name['Delete']._loaded_options = None
  _globals['_USERSERVICE'].methods_by_name['Delete']._serialized_options = b'\262\322*+\n\022DeleteUserMetadata\022\025google.protobuf.Empty\202\323\344\223\002:*8/managed-spqr/v1/clusters/{cluster_id}/users/{user_name}'
  _globals['_GETUSERREQUEST']._serialized_start=279
  _globals['_GETUSERREQUEST']._serialized_end=379
  _globals['_LISTUSERSREQUEST']._serialized_start=381
  _globals['_LISTUSERSREQUEST']._serialized_end=495
  _globals['_LISTUSERSATREVISIONREQUEST']._serialized_start=498
  _globals['_LISTUSERSATREVISIONREQUEST']._serialized_end=648
  _globals['_LISTUSERSRESPONSE']._serialized_start=650
  _globals['_LISTUSERSRESPONSE']._serialized_end=741
  _globals['_CREATEUSERREQUEST']._serialized_start=743
  _globals['_CREATEUSERREQUEST']._serialized_end=851
  _globals['_CREATEUSERMETADATA']._serialized_start=853
  _globals['_CREATEUSERMETADATA']._serialized_end=912
  _globals['_UPDATEUSERREQUEST']._serialized_start=915
  _globals['_UPDATEUSERREQUEST']._serialized_end=1257
  _globals['_UPDATEUSERMETADATA']._serialized_start=1259
  _globals['_UPDATEUSERMETADATA']._serialized_end=1318
  _globals['_DELETEUSERREQUEST']._serialized_start=1320
  _globals['_DELETEUSERREQUEST']._serialized_end=1423
  _globals['_DELETEUSERMETADATA']._serialized_start=1425
  _globals['_DELETEUSERMETADATA']._serialized_end=1484
  _globals['_USERSERVICE']._serialized_start=1487
  _globals['_USERSERVICE']._serialized_end=2544
# @@protoc_insertion_point(module_scope)
