# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/compute/v1/host_group.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/compute/v1/host_group.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from yandex.cloud.compute.v1 import maintenance_pb2 as yandex_dot_cloud_dot_compute_dot_v1_dot_maintenance__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(yandex/cloud/compute/v1/host_group.proto\x12\x17yandex.cloud.compute.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a)yandex/cloud/compute/v1/maintenance.proto\"\xa4\x04\n\tHostGroup\x12\n\n\x02id\x18\x01 \x01(\t\x12\x11\n\tfolder_id\x18\x02 \x01(\t\x12.\n\ncreated_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x05 \x01(\t\x12>\n\x06labels\x18\x06 \x03(\x0b\x32..yandex.cloud.compute.v1.HostGroup.LabelsEntry\x12\x0f\n\x07zone_id\x18\x07 \x01(\t\x12\x39\n\x06status\x18\x08 \x01(\x0e\x32).yandex.cloud.compute.v1.HostGroup.Status\x12\x0f\n\x07type_id\x18\t \x01(\t\x12\x46\n\x12maintenance_policy\x18\n \x01(\x0e\x32*.yandex.cloud.compute.v1.MaintenancePolicy\x12:\n\x0cscale_policy\x18\x0b \x01(\x0b\x32$.yandex.cloud.compute.v1.ScalePolicy\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"U\n\x06Status\x12\x16\n\x12STATUS_UNSPECIFIED\x10\x00\x12\x0c\n\x08\x43REATING\x10\x01\x12\t\n\x05READY\x10\x02\x12\x0c\n\x08UPDATING\x10\x03\x12\x0c\n\x08\x44\x45LETING\x10\x04\"\xca\x01\n\x04Host\x12\n\n\x02id\x18\x01 \x01(\t\x12\x34\n\x06status\x18\x02 \x01(\x0e\x32$.yandex.cloud.compute.v1.Host.Status\x12\x11\n\tserver_id\x18\x03 \x01(\t\x12\x39\n\x0breplacement\x18\x04 \x01(\x0b\x32$.yandex.cloud.compute.v1.Replacement\"2\n\x06Status\x12\x16\n\x12STATUS_UNSPECIFIED\x10\x00\x12\x06\n\x02UP\x10\x01\x12\x08\n\x04\x44OWN\x10\x02\"\x7f\n\x0bScalePolicy\x12\x46\n\x0b\x66ixed_scale\x18\x01 \x01(\x0b\x32/.yandex.cloud.compute.v1.ScalePolicy.FixedScaleH\x00\x1a\x1a\n\nFixedScale\x12\x0c\n\x04size\x18\x01 \x01(\x03\x42\x0c\n\nscale_type\"O\n\x0bReplacement\x12\x0f\n\x07host_id\x18\x01 \x01(\t\x12/\n\x0b\x64\x65\x61\x64line_at\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampBb\n\x1byandex.cloud.api.compute.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/compute/v1;computeb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.compute.v1.host_group_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\033yandex.cloud.api.compute.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/compute/v1;compute'
  _globals['_HOSTGROUP_LABELSENTRY']._loaded_options = None
  _globals['_HOSTGROUP_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_HOSTGROUP']._serialized_start=146
  _globals['_HOSTGROUP']._serialized_end=694
  _globals['_HOSTGROUP_LABELSENTRY']._serialized_start=562
  _globals['_HOSTGROUP_LABELSENTRY']._serialized_end=607
  _globals['_HOSTGROUP_STATUS']._serialized_start=609
  _globals['_HOSTGROUP_STATUS']._serialized_end=694
  _globals['_HOST']._serialized_start=697
  _globals['_HOST']._serialized_end=899
  _globals['_HOST_STATUS']._serialized_start=849
  _globals['_HOST_STATUS']._serialized_end=899
  _globals['_SCALEPOLICY']._serialized_start=901
  _globals['_SCALEPOLICY']._serialized_end=1028
  _globals['_SCALEPOLICY_FIXEDSCALE']._serialized_start=988
  _globals['_SCALEPOLICY_FIXEDSCALE']._serialized_end=1014
  _globals['_REPLACEMENT']._serialized_start=1030
  _globals['_REPLACEMENT']._serialized_end=1109
# @@protoc_insertion_point(module_scope)
