# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/baremetal/v1alpha/zone_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/baremetal/v1alpha/zone_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud.baremetal.v1alpha import zone_pb2 as yandex_dot_cloud_dot_baremetal_dot_v1alpha_dot_zone__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n1yandex/cloud/baremetal/v1alpha/zone_service.proto\x12\x1eyandex.cloud.baremetal.v1alpha\x1a)yandex/cloud/baremetal/v1alpha/zone.proto\x1a\x1dyandex/cloud/validation.proto\"+\n\x0eGetZoneRequest\x12\x19\n\x07zone_id\x18\x01 \x01(\tB\x08\x8a\xc8\x31\x04<=20\"J\n\x10ListZonesRequest\x12\x1c\n\tpage_size\x18\x64 \x01(\x03\x42\t\xfa\xc7\x31\x05<=100\x12\x12\n\npage_token\x18\x65 \x01(\tJ\x04\x08\x01\x10\x64\"g\n\x11ListZonesResponse\x12\x33\n\x05zones\x18\x01 \x03(\x0b\x32$.yandex.cloud.baremetal.v1alpha.Zone\x12\x17\n\x0fnext_page_token\x18\x64 \x01(\tJ\x04\x08\x02\x10\x64\x32\xdb\x01\n\x0bZoneService\x12]\n\x03Get\x12..yandex.cloud.baremetal.v1alpha.GetZoneRequest\x1a$.yandex.cloud.baremetal.v1alpha.Zone\"\x00\x12m\n\x04List\x12\x30.yandex.cloud.baremetal.v1alpha.ListZonesRequest\x1a\x31.yandex.cloud.baremetal.v1alpha.ListZonesResponse\"\x00\x42r\n\"yandex.cloud.api.baremetal.v1alphaZLgithub.com/yandex-cloud/go-genproto/yandex/cloud/baremetal/v1alpha;baremetalb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.baremetal.v1alpha.zone_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\"yandex.cloud.api.baremetal.v1alphaZLgithub.com/yandex-cloud/go-genproto/yandex/cloud/baremetal/v1alpha;baremetal'
  _globals['_GETZONEREQUEST'].fields_by_name['zone_id']._loaded_options = None
  _globals['_GETZONEREQUEST'].fields_by_name['zone_id']._serialized_options = b'\212\3101\004<=20'
  _globals['_LISTZONESREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTZONESREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\005<=100'
  _globals['_GETZONEREQUEST']._serialized_start=159
  _globals['_GETZONEREQUEST']._serialized_end=202
  _globals['_LISTZONESREQUEST']._serialized_start=204
  _globals['_LISTZONESREQUEST']._serialized_end=278
  _globals['_LISTZONESRESPONSE']._serialized_start=280
  _globals['_LISTZONESRESPONSE']._serialized_end=383
  _globals['_ZONESERVICE']._serialized_start=386
  _globals['_ZONESERVICE']._serialized_end=605
# @@protoc_insertion_point(module_scope)
